<?php
/* Revolution Slider support functions
------------------------------------------------------------------------------- */

// Theme init priorities:
// 9 - register other filters (for installer, etc.)
if ( ! function_exists( 'giardino_revslider_theme_setup9' ) ) {
	add_action( 'after_setup_theme', 'giardino_revslider_theme_setup9', 9 );
	function giardino_revslider_theme_setup9() {

		add_filter( 'giardino_filter_merge_styles', 'giardino_revslider_merge_styles' );

		if ( is_admin() ) {
			add_filter( 'giardino_filter_tgmpa_required_plugins', 'giardino_revslider_tgmpa_required_plugins' );
		}
	}
}

// Filter to add in the required plugins list
if ( ! function_exists( 'giardino_revslider_tgmpa_required_plugins' ) ) {
	
	function giardino_revslider_tgmpa_required_plugins( $list = array() ) {
		if ( giardino_storage_isset( 'required_plugins', 'revslider' ) && giardino_is_theme_activated() ) {
			$path = giardino_get_plugin_source_path( 'plugins/revslider/revslider.zip' );
			if ( ! empty( $path ) || giardino_get_theme_setting( 'tgmpa_upload' ) ) {
				$list[] = array(
					'name'     => giardino_storage_get_array( 'required_plugins', 'revslider' ),
					'slug'     => 'revslider',
					'source'   => ! empty( $path ) ? $path : 'upload://revslider.zip',
					'version'  => '6.6.14',
					'required' => false,
				);
			}
		}
		return $list;
	}
}

// Check if RevSlider installed and activated
if ( ! function_exists( 'giardino_exists_revslider' ) ) {
	function giardino_exists_revslider() {
		return function_exists( 'rev_slider_shortcode' );
	}
}

// Merge custom styles
if ( ! function_exists( 'giardino_revslider_merge_styles' ) ) {
	
	function giardino_revslider_merge_styles( $list ) {
		if ( giardino_exists_revslider() ) {
			$list[] = 'plugins/revslider/_revslider.scss';
		}
		return $list;
	}
}

// Allow loading RevSlider scripts and styles
// if it present in the content of the current page
if (!function_exists('giardino_revslider_check_revslider_in_content')) {
    add_filter( 'revslider_include_libraries', 'giardino_revslider_check_revslider_in_content' );
    function giardino_revslider_check_revslider_in_content( $load ) {
        if ( ! $load && function_exists( 'trx_addons_check_revslider_in_content' ) && giardino_is_layouts_available() ) {
            // Check slider in the page header
            if ( apply_filters( 'giardino_filter_check_revslider_in_header', true ) ) {
                $header_type = giardino_get_theme_option( 'header_type' );
                if ( 'custom' == $header_type ) {
                    $header_id = giardino_get_custom_header_id();
                    if ( $header_id > 0 ) {
                        $load = trx_addons_check_revslider_in_content( false, $header_id );
                    }
                }
            }
            // Check slider in the page footer
            if ( apply_filters( 'giardino_filter_check_revslider_in_footer', false ) ) {
                $footer_type = giardino_get_theme_option( 'footer_type' );
                if ( 'custom' == $footer_type ) {
                    $footer_id = giardino_get_custom_footer_id();
                    if ( $footer_id > 0 ) {
                        $load = trx_addons_check_revslider_in_content( false, $footer_id );
                    }
                }
            }
        }
        return $load;
    }
}